@@ -4,6 +4,7 @@ from typing import Dict, List
 
 import pluggy
 from edgetest.logger import get_logger
+from edgetest.report import gen_report
 from edgetest.schema import Schema
 from edgetest.utils import _run_command
 
@@ -141,6 +142,35 @@ def push_branch(conf: Dict):
         LOG.info("Submitting PR.")
 
 
+def create_issue(message: str):
+    """Create an issue with Hub.
+
+    Parameters
+    ----------
+    message: str
+
+
+    Returns
+    -------
+    None
+    """
+    try:
+        out, _ = _run_command(
+            HUB_COMMAND,
+            "issue",
+            "create",
+            "--message",
+            "[EDGETEST] Issue updating dependencies",
+            "--message",
+            "Edgetest ran, but there were some issues with the tests passing. Edgetest created an issue to let you know.",  # noqa: E501
+            "--message",
+            message,
+        )
+        LOG.info("Creating issue.")
+    except RuntimeError:
+        LOG.info("There was a problem creating an Issue.")
+
+
 @hookimpl
 def addoption(schema: Schema):
     """Add an email global configuration option.
@@ -150,6 +180,10 @@ def addoption(schema: Schema):
     schema : Schema
         The schema class.
     """
+
+    def to_bool(x):
+        return x.lower() in ["true", "1"]
+
     schema.add_globaloption(
         "hub",
         {
@@ -195,6 +229,11 @@ def addoption(schema: Schema):
                     "coerce": "strip",
                     "required": True,
                 },
+                "open_issue_on_fail": {
+                    "type": "boolean",
+                    "coerce": to_bool,
+                    "required": True,
+                },
             },
         },
     )
@@ -203,11 +242,19 @@ def addoption(schema: Schema):
 @hookimpl
 def post_run_hook(testers: List, conf: Dict):
     """Invoke hub after the testing is complete."""
-    if (
-        testers[-1].status and GIT_TOKEN_ENVNAME in os.environ
-    ):  # skip is token not available
-        if conf.get("hub"):
-            configure_branch(conf)
-            push_branch(conf)
+    if GIT_TOKEN_ENVNAME in os.environ:
+        if testers[-1].status is True:
+            if conf.get("hub"):
+                configure_branch(conf)
+                push_branch(conf)
+        else:  # testers[-1].status is False
+            if conf.get("hub"):
+                if conf["hub"]["open_issue_on_fail"] is True:
+                    report = gen_report(testers, output_type="github")
+                    create_issue(report)
+                else:
+                    LOG.info("Skipping Creating an Issue.")
+            else:
+                LOG.info("Hub plugin configuration not found. Skipping Hub plugin")
     else:
         LOG.info("Environment variable GITHUB_TOKEN not found. Skipping Hub plugin.")
